@@ -20,11 +20,18 @@
 #endif
 
 #include <iostream>
+#ifdef HAVE_GETTEXT
+#include <libintl.h>
+#define _(String) gettext (String)
+#else
+#define _(String) (String)
+#endif
 	
 #include "gameengine.h"
 #include "surfacemanager.h"
+#include "fontmanager.h"
 #include "soundmanager.h"
-#include "SFont.h"
+#include "Font.hpp"
 #include "controller.h"
 
 #include "menu.h"
@@ -53,7 +60,6 @@
 #include "matchfinishedstate.h"
 #include "videomenustate.h"
 #include "const.h"
-#include <libintl.h>
 
 Player *GameEngine::s_lastTouch=0;
 
@@ -126,34 +132,31 @@ GameEngine::GameEngine(bool fullscreen) :
 		m_scoreFont = NULL;
 	} else {
 		// Load Fonts
-		std::string str = "graphics/24P_Copperplate_Blue.png";
-		m_nameFont = SurfaceManager::instance()->load(m_screen->format, str, false, true);
-		str = "graphics/24P_Arial_NeonYellow.png";
-		m_scoreFont = SurfaceManager::instance()->load(m_screen->format, str, false, true);
-
-		// Use the score font
-		InitFont(m_scoreFont);
+		std::string str = "graphics/font_yellow.png";
+		m_nameFont = FontManager::instance()->load(m_screen->format, str, false, true);
+		str = "graphics/font_white.png";
+		m_scoreFont = FontManager::instance()->load(m_screen->format, str, false, true);
 
 		// Write out text to show our starting progress
-		PutString(m_screen, 10, 10, gettext("Starting Renderer"));
+		m_scoreFont->write(m_screen, _("Starting Renderer"), 10, 10);
 		SDL_Flip(m_screen);
 		m_renderer = new Graphics(m_screen);
 
-		PutString(m_screen, 10, 40, gettext("Loading Pitch"));
+		m_scoreFont->write(m_screen, _("Loading Pitch"), 10, 40);
 		SDL_Flip(m_screen);
 		m_pitch = new Pitch(m_renderer);
 
-		PutString(m_screen, 10, 70, gettext("Loading Ball"));
+		m_scoreFont->write(m_screen, _("Loading Ball"), 10, 70);
 		SDL_Flip(m_screen);
 		m_ball = new Ball(m_renderer, m_pitch);
 
-		PutString(m_screen, 10, 100, gettext("Loading Team 1"));
+		m_scoreFont->write(m_screen, _("Loading Team 1"), 10, 100);
 		SDL_Flip(m_screen);
-		m_homeTeam = new Team(this, "Blue Utd.", "team1", "graphics/homeplayermarker.tga", m_pitch, m_ball, true);
+		m_homeTeam = new Team(this, "Blue Utd.", "BLU", "team1", "graphics/homeplayermarker.png", m_pitch, m_ball, true);
 
-		PutString(m_screen, 10, 130, gettext("Loading Team 2"));
+		m_scoreFont->write(m_screen, _("Loading Team 2"), 10, 130);
 		SDL_Flip(m_screen);
-		m_awayTeam = new Team(this, "Red City", "team2", "graphics/awayplayermarker.tga", m_pitch, m_ball, false);
+		m_awayTeam = new Team(this, "Red City", "RED", "team2", "graphics/awayplayermarker.png", m_pitch, m_ball, false);
 	}
 
 	SDL_Rect r = {m_resX/2, m_resY/2, m_pitch->width()-(m_resX), m_pitch->height()-(m_resY)};
@@ -164,7 +167,7 @@ GameEngine::GameEngine(bool fullscreen) :
 	r.h = m_resY;
 	m_camera.setScreenRect(r);
 
-	m_homeController = new Controller(m_homeTeam, m_awayTeam, SDLK_UP, SDLK_DOWN, SDLK_LEFT, SDLK_RIGHT, SDLK_c, SDLK_v, false, m_ball, m_pitch);
+	m_homeController = new Controller(m_homeTeam, m_awayTeam, SDLK_UP, SDLK_DOWN, SDLK_LEFT, SDLK_RIGHT, SDLK_LSHIFT, SDLK_LCTRL, false, m_ball, m_pitch);
 	m_awayController = new Controller(m_awayTeam, m_homeTeam, SDLK_k, SDLK_j, SDLK_h, SDLK_l, SDLK_f, SDLK_g, true, m_ball, m_pitch);
 
 	m_menu = 0;
@@ -190,6 +193,8 @@ GameEngine::GameEngine(bool fullscreen) :
 	m_gameStates.push_back( new PenaltyShootoutState(*this) );
 	m_gameStates.push_back( new MatchAbortedState(*this) );
 	m_gameStates.push_back( new MatchFinishedState(*this) );
+
+	m_score = SurfaceManager::instance()->load(m_screen->format, "graphics/score.png", false, true);
 }
 
 GameEngine::~GameEngine()
@@ -202,8 +207,10 @@ GameEngine::~GameEngine()
 	if(m_awayController) delete m_awayController;
 	if(m_renderer) delete m_renderer;
 
-	if(m_nameFont) SurfaceManager::instance()->release(m_nameFont);
-	if(m_scoreFont) SurfaceManager::instance()->release(m_scoreFont);
+	if(m_score) SurfaceManager::instance()->release(m_score);
+	
+	if(m_nameFont) FontManager::instance()->release(m_nameFont);
+	if(m_scoreFont) FontManager::instance()->release(m_scoreFont);
 
 	std::vector<Mix_Chunk *>::iterator it = m_sounds.begin();
 	while(it != m_sounds.end())
@@ -367,7 +374,7 @@ void GameEngine::iterateEngine()
 void GameEngine::drawFrame()
 {
 	static int x = 0;
-	SDL_Rect r, s;
+	SDL_Rect r, s, score_pos, score_size;
 	x+=2;
 	
 	int left = (int)m_camera.position().x() - m_resX/2;
@@ -379,39 +386,60 @@ void GameEngine::drawFrame()
 	m_renderer->draw(left, top);
 
 	if(m_gameInProgress) {
+
+		//
+		// Draw Score background
+		//
+		if(m_score) {
+			score_size.x = 0;
+			score_size.y = 0;
+			score_size.w = 298;
+			score_size.h = 28;
+			score_pos.x = m_screen->w - score_size.w - 10;
+			score_pos.y = 10;
+			score_pos.w = 298;
+			score_pos.h = 28;
+			if(SDL_BlitSurface(m_score, &score_size, m_screen, &score_pos) < 0) {
+				std::cerr << "Error - could not blit score : " << SDL_GetError() << std::endl;
+			}
+		}
+
 		//
 		// Draw Score
 		//
-	
-		InitFont(m_scoreFont);
-	
-		std::ostringstream str1;
-		std::ostringstream str2;
-	
-		str1 << m_homeScore;
-		str2 << m_awayScore;	
-	
-		int scoreWidth = TextWidth(str1.str().c_str());
-		scoreWidth = (scoreWidth < TextWidth(str2.str().c_str())) ? scoreWidth : TextWidth(str2.str().c_str());
+		std::ostringstream homeScoreStr;
+		std::ostringstream awayScoreStr;
+
+		homeScoreStr << m_homeScore;
+		awayScoreStr << m_awayScore;	
+
+		m_scoreFont->write(m_screen, homeScoreStr.str().c_str(), m_screen->w-228, 12);
+		m_scoreFont->write(m_screen, "-", m_screen->w-207, 12);
+		m_scoreFont->write(m_screen, awayScoreStr.str().c_str(), m_screen->w-193, 12);
+
+		m_nameFont->write(m_screen, m_homeTeam->shortname().c_str(), 
+			  m_screen->w-295, 12);
+		m_nameFont->write(m_screen, m_awayTeam->shortname().c_str(), 
+			  m_screen->w-160, 12);
+
+		
+		int scoreWidth = m_scoreFont->getTextWidth(homeScoreStr.str().c_str());
+		scoreWidth = (scoreWidth < m_scoreFont->getTextWidth(awayScoreStr.str().c_str())) ? scoreWidth : m_scoreFont->getTextWidth(awayScoreStr.str().c_str());
 		scoreWidth += 20;
 
 		int sm = m_screen->w/2;
 
-		PutString(m_screen, sm - scoreWidth, m_screen->h-34, str1.str().c_str());
-		PutString(m_screen, sm + 20, m_screen->h-34, str2.str().c_str());
+		m_scoreFont->write(m_screen, homeScoreStr.str().c_str(), sm - scoreWidth, m_screen->h-34);
+		m_scoreFont->write(m_screen, awayScoreStr.str().c_str(), sm + 20, m_screen->h-34);
 	
-		InitFont(m_nameFont);
-		
-		PutString(m_screen, 
-			  sm - scoreWidth - TextWidth(m_homeTeam->name().c_str())-20, m_screen->h-34,
-			  m_homeTeam->name().c_str());
-		PutString(m_screen, 
-			  sm+scoreWidth+20, m_screen->h-34, m_awayTeam->name().c_str());
+		m_nameFont->write(m_screen, m_homeTeam->name().c_str(), 
+			  sm - scoreWidth - m_nameFont->getTextWidth(m_homeTeam->name().c_str())-20, m_screen->h-34);
+		m_nameFont->write(m_screen, m_awayTeam->name().c_str(), 
+			  sm+scoreWidth+20, m_screen->h-34);
 
 		//
 		// Draw Time
 		//
-		InitFont(m_scoreFont);
 		std::ostringstream str3;
 		int minutes = ((2700 * m_timer)/m_halfLength)%60;
 	
@@ -420,20 +448,18 @@ void GameEngine::drawFrame()
 		} else {
 			str3 << ((2700 * m_timer)/m_halfLength)/60 << ":" << ((2700 * m_timer)/m_halfLength)%60;
 		}
-		PutString(m_screen, 10, 10, str3.str().c_str());
+		
+		m_scoreFont->write(m_screen, str3.str().c_str(), m_screen->w - m_scoreFont->getTextWidth(str3.str().c_str()) - 22, 12);
 	}
 
 	//
 	// Draw frames per second
 	// 
 	if(m_displayFPS) {
-		InitFont(m_scoreFont);
-
 		std::ostringstream str4;
 		str4 << "FPS : " << m_framesPerSecond;
-		PutString(m_screen, m_screen->w - 10 - TextWidth(str4.str().c_str()), 10, str4.str().c_str());
+		m_scoreFont->write(m_screen, str4.str().c_str(), m_screen->w - 10 - m_scoreFont->getTextWidth(str4.str().c_str()), 40);
 	}
-	
 
 	//
 	// Draw Menu
@@ -478,7 +504,7 @@ GameEngine::TimerState GameEngine::timerState() const
 	return m_timerState;
 }
 
-int GameEngine::timer() const
+uint GameEngine::timer() const
 {
 	return m_timer;
 }
