@@ -82,7 +82,7 @@ Player::Player(Graphics *renderer, std::string skin, std::string playerMarker, P
 	SDL_Rect sr = {-32, -54, 0, 0};
 	SDL_Rect sh = {-14, -60, 0, 0};
 	SDL_Rect sa = {-16, -60, 0, 0};	
-	m_object = new SpriteObject(NULL, m_shadow, NULL, position(), sr, sh, sa);
+	m_object = new SpriteObject(NULL, NULL, NULL, position(), sr, sh, sa);
 	m_renderer->addSprite(m_object);
 
 	m_goalie = goalie;
@@ -96,7 +96,6 @@ Player::~Player()
 	delete m_header;
 	delete m_tackle;
 	delete m_object;
-	SurfaceManager::instance()->release(m_shadow);
 	SurfaceManager::instance()->release(m_active);
 }
 
@@ -196,22 +195,19 @@ void Player::loadSpriteSurfaces(std::string skin, std::string playerMarker)
 {
 	if(m_renderer && m_renderer->screen()) {
 		m_walk = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/walking", 48, true);
+								"graphics/"+skin+"/walking", "walking", 40, true, true);
 		m_stand = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/standing", 1, true);
+								"graphics/"+skin+"/standing", "standing", 1, true, true);
 		m_run = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/running", 48, true);
+								"graphics/"+skin+"/running", "running", 40, true, true);
 		m_tackle = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/tackling", 12, false);
+								"graphics/"+skin+"/tackling", "tackling", 25, false, true);
 		m_header = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/header", 12, false);
-		m_shadow = SurfaceManager::instance()->load(m_renderer->screen()->format, 
-								"graphics/shadow.tga", true, false);
+								"graphics/"+skin+"/header", "header", 20, false, true);
 		m_active = SurfaceManager::instance()->load(m_renderer->screen()->format, playerMarker, true, false);
 	} else {
 		std::cerr << "Error - cannot load Player Sprite surfaces, problem with renderer" << std::endl;
 		m_walk = m_stand = m_run = m_tackle = NULL;
-		m_shadow = m_active = NULL;
 	}
 }
 
